==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/synthetics_canary/SyntheticsCanaryArtifactConfig.java <==
package com.hashicorp.cdktf.providers.aws.synthetics_canary;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.934Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.syntheticsCanary.SyntheticsCanaryArtifactConfig")
@software.amazon.jsii.Jsii.Proxy(SyntheticsCanaryArtifactConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SyntheticsCanaryArtifactConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * s3_encryption block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_encryption SyntheticsCanary#s3_encryption}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption getS3Encryption() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SyntheticsCanaryArtifactConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SyntheticsCanaryArtifactConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SyntheticsCanaryArtifactConfig> {
        com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption s3Encryption;

        /**
         * Sets the value of {@link SyntheticsCanaryArtifactConfig#getS3Encryption}
         * @param s3Encryption s3_encryption block.
         *                     Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_encryption SyntheticsCanary#s3_encryption}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3Encryption(com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption s3Encryption) {
            this.s3Encryption = s3Encryption;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SyntheticsCanaryArtifactConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SyntheticsCanaryArtifactConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SyntheticsCanaryArtifactConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SyntheticsCanaryArtifactConfig {
        private final com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption s3Encryption;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.s3Encryption = software.amazon.jsii.Kernel.get(this, "s3Encryption", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.s3Encryption = builder.s3Encryption;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption getS3Encryption() {
            return this.s3Encryption;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getS3Encryption() != null) {
                data.set("s3Encryption", om.valueToTree(this.getS3Encryption()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.syntheticsCanary.SyntheticsCanaryArtifactConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SyntheticsCanaryArtifactConfig.Jsii$Proxy that = (SyntheticsCanaryArtifactConfig.Jsii$Proxy) o;

            return this.s3Encryption != null ? this.s3Encryption.equals(that.s3Encryption) : that.s3Encryption == null;
        }

        @Override
        public final int hashCode() {
            int result = this.s3Encryption != null ? this.s3Encryption.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/synthetics_canary/SyntheticsCanaryArtifactConfig.java <==
package com.hashicorp.cdktf.providers.aws.synthetics_canary;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.983Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.syntheticsCanary.SyntheticsCanaryArtifactConfig")
@software.amazon.jsii.Jsii.Proxy(SyntheticsCanaryArtifactConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SyntheticsCanaryArtifactConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * s3_encryption block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/synthetics_canary#s3_encryption SyntheticsCanary#s3_encryption}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption getS3Encryption() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SyntheticsCanaryArtifactConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SyntheticsCanaryArtifactConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SyntheticsCanaryArtifactConfig> {
        com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption s3Encryption;

        /**
         * Sets the value of {@link SyntheticsCanaryArtifactConfig#getS3Encryption}
         * @param s3Encryption s3_encryption block.
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/synthetics_canary#s3_encryption SyntheticsCanary#s3_encryption}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3Encryption(com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption s3Encryption) {
            this.s3Encryption = s3Encryption;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SyntheticsCanaryArtifactConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SyntheticsCanaryArtifactConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SyntheticsCanaryArtifactConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SyntheticsCanaryArtifactConfig {
        private final com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption s3Encryption;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.s3Encryption = software.amazon.jsii.Kernel.get(this, "s3Encryption", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.s3Encryption = builder.s3Encryption;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.synthetics_canary.SyntheticsCanaryArtifactConfigS3Encryption getS3Encryption() {
            return this.s3Encryption;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getS3Encryption() != null) {
                data.set("s3Encryption", om.valueToTree(this.getS3Encryption()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.syntheticsCanary.SyntheticsCanaryArtifactConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SyntheticsCanaryArtifactConfig.Jsii$Proxy that = (SyntheticsCanaryArtifactConfig.Jsii$Proxy) o;

            return this.s3Encryption != null ? this.s3Encryption.equals(that.s3Encryption) : that.s3Encryption == null;
        }

        @Override
        public final int hashCode() {
            int result = this.s3Encryption != null ? this.s3Encryption.hashCode() : 0;
            return result;
        }
    }
}
